Before & After: A Year of IKEA Hacks — Best of 2014 | Apartment Therapy
Description: Nothing stirs the DIY spirit like a good IKEA hack. IKEA is so accessible — anybody could stroll in there and buy a BEKVAM or two — but its Scandinavian design is deceptively simple. With a little ingenuity a box, or a table, or a stool from IKEA could become pretty much anything. Here's proof.

# Before & After: A Year of IKEA Hacks

Best of 2014

Nothing stirs the DIY spirit like a good IKEA hack. IKEA is so accessible — anybody could stroll in there and buy a BEKVAM or two — but its Scandinavian design is deceptively simple. With a little ingenuity a box, or a table, or a stool from IKEA could become pretty much anything. Here's proof.

Open Slideshow

Click on the slideshow to see the projects. To learn more about each project (and see more pictures), click the links in the captions.

→ Welcome to Apartment Therapy's Best of 2014 roundup!
From December 21 through January 1 we are rounding up our favorite (and your favorite) posts from the past year.

(Image credits: IKEA; Soffia Gardarsdottir; Brynne Delerson; Northstory; IKEA; Papotologie; IKEA; Kristi Murphy; Design Stoke; Jacob Gibbs; IKEA; IKEA Hackers; IKEA; Kristi Murphy; Alyssa Valentine; IKEA; Pinterest user Hanna; Instructables; IKEA; Kata Szentgyorgyi; IKEA; Clara Arnsberger; In the Hollow Heart; Brit Pierce; IKEA; Yes Spaces; Joy; IKEA; Krys Melo; IKEA; Reddit)

## Maxwell’s Daily Find

1. Meyer Lemon Tree
2. de Buyer Copper Sauce Pans
3. Takenaka Bento Boxes

See more

### Around the Web